# vim:ft=sh:ts=2:et
# This file is public domain software, written by Robert Luberda <robert@debian.org>
# Adapted from iceape-locale-pl's debian/rules, which was
# based on  mozilla-locale-fr (maintained by Aurelien Jarno <aurel32@debian.org>)
# which was mostly taken from mozilla-locale-ja (maintained by 
# Takuo Kitame <kitame@northeye.org>

set -e
unset CDPATH ENV
CURDIR=`pwd` 
BUILDDIR="$CURDIR/debian/BUILD/UNPACK"
JARDIR="$CURDIR/debian/BUILD/JARS"
PATCHDIR="$CURDIR/debian/BUILD/PATCHES"

rm -rf "$BUILDDIR" "$JARDIR" "$PATCHDIR"
mkdir -p "$BUILDDIR" "$JARDIR" "$PATCHDIR"

## Helper functions
msg_start() {
  printf "%-75.75s" "$1"
}

msg_end() {
  echo "${1:-done}"
}  


## Does base rebranding: s/SeaMonkey/Iceape/g in most files
## Additionaly sets home page to "about:"
rebranding_base() {
  local jardir="$1"
  for file in `find "$jardir" -path "*/navigator-region/*" -name "region.properties"`; do
    msg_start "** Updating home page in $file..."
    sed -e 's|^ *\(homePageDefault\) *=.*|\1=http://www.debian.org/|' \
        -e 's|^ *\(browser\.startup\.homepage\) *=.*|\1=about:|' \
        -e 's|^ *\(startup.homepage_override_url\) *=.*|\1=about:|' \
        < "$file" > "$file.tmp"
    mv -f "$file.tmp" "$file"
    msg_end
  done    

  for file in `find "$jardir" -path "*/branding/*" -name "brand.properties"`; do
    msg_start "** Rebranding $file..."
    sed -e 's|^ *\(brandFullName\) *=.*|\1=Iceape|' \
        -e 's|^ *\(brandShortName\) *=.*|\1=Iceape|' \
        -e 's|^ *\(vendorShortName\) *=.*|\1=Debian|' \
        < "$file" > "$file.tmp"
    mv -f "$file.tmp" "$file"
    msg_end
  done    

  for file in `find "$jardir" -path "*/branding/*" -name "brand.dtd"`; do
    msg_start "** Rebranding $file..."
    sed -e 's|^ *\(<!ENTITY *brandFullName *"\).*\(" *>\) *|\1Iceape\2|' \
        -e 's|^ *\(<!ENTITY *brandShortName *"\).*\(" *>\) *|\1Iceape\2|' \
        -e 's|^ *\(<!ENTITY *vendorShortName *"\).*\(" *>\) *|\1Debian\2|' \
        < "$file" > "$file.tmp"
    mv -f "$file.tmp" "$file"
    msg_end
  done    

  for file in `find "$jardir" \( -name "*.*htm*" -o -name "*.dtd" -o -name "*.properties" -o -name "*.rdf" \)`; do 
    grep  -q "Sea[mM]onkey" "$file" || continue              
    msg_start "** Rebranding $file..."    
    sed -e 's|Sea[mM]onkey|Iceape|g' < "$file" > "$file.tmp"
    mv -f "$file.tmp" "$file"
    msg_end
  done    


# replace &vendorShortName; with Iceape (i.e. &brandShortName) in the profile manager'
# start.label ENTITY
  for file in `find "$jardir"  -path "*/profile/*" -name "profileSelection.dtd" `; do 
    grep  -q "start\.label.*vendorShortName" "$file" || continue              
    msg_start "** Rebranding $file..."    
    sed -e 's|\(ENTITY.*start\.label.*\)&vendorShortName;|\1Iceape|g' < "$file" > "$file.tmp"
    mv -f "$file.tmp" "$file"
    msg_end
  done    

}  


## Main function

echo; msg_start "* Unpacking upstream *.xpi files..."
for xpifile in `find "$CURDIR/upstream" -maxdepth 1 -type f -iname '*.xpi'` ; do
  xpi=`basename "$xpifile" .xpi`
  mkdir -p "$BUILDDIR/$xpi"
  unzip -q "$xpifile" -d "$BUILDDIR/$xpi"            
done
msg_end; msg_end " "



cd "$BUILDDIR"
for jarfile in `find "." -path "*/chrome/*" \( -name "??.jar" -o -name "??-??.jar" -o -name "??-unix.jar" -o -name "??-??-unix.jar" \)`; do       
  jar=`basename "$jarfile" .jar`
  jardir=`dirname "$jarfile"`
  
  msg_start "* Unpacking $jar.jar..."
  unzip -q "$jarfile" -d "$jardir/$jar.orig"
  cp -a "$jardir/$jar.orig" "$jardir/$jar"
  msg_end

  cd "$jardir/$jar"
  rebranding_base "locale"


  for patch in `cd $CURDIR/debian/patches/; ls -1 "${jar}"_* 2>/dev/null` ; do 
    msg_start "** Applying patch $patch..." ; msg_end " "
    if ! patch -p0 < "$CURDIR/debian/patches/$patch" ;  then 
      msg_start "*** Patch $patch:"; msg_end "FAIL"
      exit 1 
    else 
      msg_start "*** Patch $patch:"; msg_end "ok"
    fi 
  done 

  msg_start "* Creating $jar.jar..."
  zip -q -r -9 "$JARDIR/$jar.jar" locale
  cd ".."  
  diff -Nur "$jar.orig" "$jar" > "$PATCHDIR/$jar.diff" || true


  cd "$BUILDDIR"
  msg_end ; msg_end " "
done

